@@ -118,6 +118,7 @@ func createOutputs(
 		ScriptOptions:  test.derivedConfig.Options,
 		RuntimeOptions: test.preInitState.RuntimeOptions,
 		ExecutionPlan:  executionPlan,
+		Usage:          test.preInitState.Usage,
 	}
 
 	outputs := test.derivedConfig.Out
@@ -136,6 +137,12 @@ func createOutputs(
 				outputType, getPossibleIDList(outputConstructors),
 			)
 		}
+		if _, builtinErr := builtinOutputString(outputType); builtinErr == nil {
+			err := test.preInitState.Usage.Strings("outputs", outputType)
+			if err != nil {
+				gs.Logger.WithError(err).Warnf("Couldn't report usage for output %q", outputType)
+			}
+		}
 
 		params := baseParams
 		params.OutputType = outputType
@@ -155,6 +162,14 @@ func createOutputs(
 			builtinMetricOut.SetBuiltinMetrics(test.preInitState.BuiltinMetrics)
 		}
 
+		// If the output is configured to support the archive, and supports it, we proceed
+		// with building an archive and setting it on the output instance.
+		if !test.derivedConfig.NoArchiveUpload.Bool {
+			if archiveOut, ok := out.(output.WithArchive); ok {
+				archiveOut.SetArchive(test.initRunner.MakeArchive())
+			}
+		}
+
 		result = append(result, out)
 	}
 
