@@ -26,6 +26,7 @@ import (
 	"go.k6.io/k6/lib/types"
 	"go.k6.io/k6/loader"
 	"go.k6.io/k6/metrics"
+	"go.k6.io/k6/usage"
 )
 
 const isWindows = runtime.GOOS == "windows"
@@ -43,6 +44,7 @@ func getTestPreInitState(tb testing.TB, logger logrus.FieldLogger, rtOpts *lib.R
 		RuntimeOptions: *rtOpts,
 		Registry:       reg,
 		BuiltinMetrics: metrics.RegisterBuiltinMetrics(reg),
+		Usage:          usage.New(),
 	}
 }
 
@@ -189,13 +191,6 @@ func TestNewBundle(t *testing.T) {
 					"InvalidCompat", "es1", `export default function() {};`,
 					`invalid compatibility mode "es1". Use: "extended", "base", "experimental_enhanced"`,
 				},
-				// BigInt is not supported
-				{
-					"BigInt", "base",
-					`module.exports.default = function() {};
-BigInt(1231412444)`,
-					"ReferenceError: BigInt is not defined\n\tat file:///script.js:2:7(7)\n",
-				},
 			}
 
 			for _, tc := range testCases {
@@ -219,6 +214,16 @@ BigInt(1231412444)`,
 			`)
 			require.NoError(t, err)
 		})
+		t.Run("Null", func(t *testing.T) {
+			t.Parallel()
+			fs := fsext.NewMemMapFs()
+			require.NoError(t, fsext.WriteFile(fs, "/options.js", []byte("module.exports={}"), 0o644))
+			_, err := getSimpleBundle(t, "/script.js", `
+				export {options} from "./options.js";
+				export default function() {};
+			`, fs)
+			require.NoError(t, err)
+		})
 		t.Run("Invalid", func(t *testing.T) {
 			t.Parallel()
 			invalidOptions := map[string]struct {
