@@ -7,13 +7,15 @@ package fs
 import (
 	"errors"
 	"fmt"
+	"io"
 	"reflect"
 
+	"go.k6.io/k6/lib/fsext"
+
 	"github.com/grafana/sobek"
 	"go.k6.io/k6/js/common"
 	"go.k6.io/k6/js/modules"
 	"go.k6.io/k6/js/promises"
-	"go.k6.io/k6/lib/fsext"
 )
 
 type (
@@ -135,15 +137,37 @@ func (mi *ModuleInstance) openImpl(path string) (*File, error) {
 		return nil, err
 	}
 
-	return &File{
+	file := &File{
 		Path: path,
-		file: file{
+		ReadSeekStater: &file{
 			path: path,
 			data: data,
 		},
 		vu:    mi.vu,
 		cache: mi.cache,
-	}, nil
+	}
+
+	return file, nil
+}
+
+// Stater is an interface that provides information about a file.
+//
+// Although in the context of this module we have a single implementation
+// of this interface, it is defined to allow exposing the `file`'s behavior
+// to other module through the `ReadSeekStater` interface without having to
+// leak our internal abstraction.
+type Stater interface {
+	// Stat returns a FileInfo describing the named file.
+	Stat() *FileInfo
+}
+
+// ReadSeekStater is an interface that combines the io.ReadSeeker and Stater
+// interfaces and ensure that structs implementing it have the necessary
+// methods to interact with files.
+type ReadSeekStater interface {
+	io.Reader
+	io.Seeker
+	Stater
 }
 
 // File represents a file and exposes methods to interact with it.
@@ -154,8 +178,14 @@ type File struct {
 	// Path holds the name of the file, as presented to [Open].
 	Path string `json:"path"`
 
-	// file contains the actual implementation for the file system.
-	file
+	// ReadSeekStater contains the actual implementation of the file logic, and
+	// interacts with the underlying file system.
+	//
+	// Note that we explicitly omit exposing this to JS to avoid leaking
+	// implementation details, but keep it public so that we can access it
+	// from other modules that would want to leverage its implementation of
+	// io.Reader and io.Seeker.
+	ReadSeekStater ReadSeekStater `js:"-"`
 
 	// vu holds a reference to the VU this file is associated with.
 	//
@@ -175,7 +205,7 @@ func (f *File) Stat() *sobek.Promise {
 	promise, resolve, _ := promises.New(f.vu)
 
 	go func() {
-		resolve(f.file.stat())
+		resolve(f.ReadSeekStater.Stat())
 	}()
 
 	return promise
@@ -220,7 +250,7 @@ func (f *File) Read(into sobek.Value) *sobek.Promise {
 	// occurs on the main thread, during the promise's resolution.
 	callback := f.vu.RegisterCallback()
 	go func() {
-		n, readErr := f.file.Read(buffer)
+		n, readErr := f.ReadSeekStater.Read(buffer)
 		callback(func() error {
 			_ = copy(intoBytes[0:n], buffer)
 
@@ -231,9 +261,14 @@ func (f *File) Read(into sobek.Value) *sobek.Promise {
 				return nil
 			}
 
+			// If the read operation failed, we need to check if it was an io.EOF error
+			// and match it to its fsError counterpart if that's the case.
+			if errors.Is(readErr, io.EOF) {
+				readErr = newFsError(EOFError, "read() failed; reason: EOF")
+			}
+
 			var fsErr *fsError
 			isFSErr := errors.As(readErr, &fsErr)
-
 			if !isFSErr {
 				reject(readErr)
 				return nil
@@ -283,7 +318,7 @@ func (f *File) Seek(offset sobek.Value, whence sobek.Value) *sobek.Promise {
 
 	callback := f.vu.RegisterCallback()
 	go func() {
-		newOffset, err := f.file.Seek(intOffset, seekMode)
+		newOffset, err := f.ReadSeekStater.Seek(intOffset, seekMode)
 		callback(func() error {
 			if err != nil {
 				reject(err)
