@@ -4,7 +4,7 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/dop251/goja"
+	"github.com/grafana/sobek"
 	"github.com/stretchr/testify/require"
 )
 
@@ -13,7 +13,7 @@ func TestHTTPFile(t *testing.T) {
 	input := []byte{104, 101, 108, 108, 111}
 
 	testCases := []struct {
-		input    func(rt *goja.Runtime) interface{}
+		input    func(rt *sobek.Runtime) interface{}
 		args     []string
 		expected FileData
 		expErr   string
@@ -22,24 +22,24 @@ func TestHTTPFile(t *testing.T) {
 		// as File() calls time.Now(), so we'd need some time freezing/mocking
 		// or refactoring, or to exclude the field from the assertion.
 		{
-			func(*goja.Runtime) interface{} { return input },
+			func(*sobek.Runtime) interface{} { return input },
 			[]string{"test.bin"},
 			FileData{Data: input, Filename: "test.bin", ContentType: "application/octet-stream"},
 			"",
 		},
 		{
-			func(*goja.Runtime) interface{} { return string(input) },
+			func(*sobek.Runtime) interface{} { return string(input) },
 			[]string{"test.txt", "text/plain"},
 			FileData{Data: input, Filename: "test.txt", ContentType: "text/plain"},
 			"",
 		},
 		{
-			func(rt *goja.Runtime) interface{} { return rt.NewArrayBuffer(input) },
+			func(rt *sobek.Runtime) interface{} { return rt.NewArrayBuffer(input) },
 			[]string{"test-ab.bin"},
 			FileData{Data: input, Filename: "test-ab.bin", ContentType: "application/octet-stream"},
 			"",
 		},
-		{func(*goja.Runtime) interface{} { return struct{}{} }, []string{}, FileData{}, "GoError: invalid type struct {}, expected string, []byte or ArrayBuffer"},
+		{func(*sobek.Runtime) interface{} { return struct{}{} }, []string{}, FileData{}, "GoError: invalid type struct {}, expected string, []byte or ArrayBuffer"},
 	}
 
 	for i, tc := range testCases {
@@ -48,13 +48,13 @@ func TestHTTPFile(t *testing.T) {
 			t.Parallel()
 			runtime, mi := getTestModuleInstance(t)
 			rt := runtime.VU.RuntimeField
-			cal, _ := goja.AssertFunction(rt.ToValue(mi.file))
-			args := make([]goja.Value, 1, len(tc.args)+1)
+			cal, _ := sobek.AssertFunction(rt.ToValue(mi.file))
+			args := make([]sobek.Value, 1, len(tc.args)+1)
 			args[0] = rt.ToValue(tc.input(rt))
 			for _, arg := range tc.args {
 				args = append(args, rt.ToValue(arg))
 			}
-			_, err := cal(goja.Undefined(), args...)
+			_, err := cal(sobek.Undefined(), args...)
 			if tc.expErr != "" {
 				require.EqualError(t, err, tc.expErr)
 			} else {
