@@ -234,8 +234,8 @@ func TestEnabledTagsMarshalJSON(t *testing.T) {
 	}
 
 	for _, tc := range tests {
-		ts := &tc.tagset
-		got, err := json.Marshal(ts)
+		ts := tc.tagset
+		got, err := json.Marshal(&ts)
 		require.Nil(t, err)
 		require.Equal(t, tc.expected, string(got))
 	}
